@@ -23,8 +23,8 @@
 
 #include "kunitconversion/kunitconversion_export.h"
 
-#include <QtCore/QString>
-#include <QtCore/QExplicitlySharedDataPointer>
+#include <QString>
+#include <QExplicitlySharedDataPointer>
 
 class KLocalizedString;
 
@@ -61,7 +61,11 @@ enum CategoryId {
     /** @since 5.27 */
     ElectricalCurrentCategory,
     /** @since 5.27 */
-    ElectricalResistanceCategory
+    ElectricalResistanceCategory,
+    /** @since 5.53 */
+    PermeabilityCategory,
+    /** @since 5.61 **/
+    BinaryDataCategory
 };
 
 enum UnitId {
@@ -91,6 +95,10 @@ enum UnitId {
     Hectoliter, Decaliter, Liter, Deciliter, Centiliter, Milliliter, Microliter, Nanoliter,
     Picoliter, Femtoliter, Attoliter, Zeptoliter, Yoctoliter, CubicFoot, CubicInch, CubicMile,
     FluidOunce, Cup, GallonUS, PintImperial,
+    /** @since 5.53 */
+    OilBarrel,
+    /** @since 5.70 */
+    GallonImperial, PintUS,
 
     // Mass
     Yottagram = 4000, Zettagram, Exagram, Petagram, Teragram, Gigagram, Megagram, Kilogram,
@@ -124,7 +132,7 @@ enum UnitId {
     // Currency
     Eur = 8000, Ats, Bef, Nlg, Fim, Frf, Dem, Iep, Itl, Luf, Pte, Esp, Grd, Sit, Cyp, Mtl, Skk,
     Usd, Jpy, Bgn, Czk, Dkk, Eek, Gbp, Huf, Ltl, Lvl, Pln, Ron, Sek, Chf, Nok, Hrk, Rub, Try,
-    Aud, Brl, Cad, Cny, Hkd, Idr, Inr, Krw, Mxn, Myr, Nzd, Php, Sgd, Thb, Zar, Ils,
+    Aud, Brl, Cad, Cny, Hkd, Idr, Inr, Krw, Mxn, Myr, Nzd, Php, Sgd, Thb, Zar, Ils, Isk,
 
     // Velocity
     MeterPerSecond = 9000, KilometerPerHour, MilePerHour, FootPerSecond, InchPerSecond, Knot,
@@ -134,6 +142,8 @@ enum UnitId {
     Yottawatt = 10000, Zettawatt, Exawatt, Petawatt, Terawatt, Gigawatt, Megawatt, Kilowatt,
     Hectowatt, Decawatt, Watt, Deciwatt, Centiwatt, Milliwatt, Microwatt, Nanowatt, Picowatt,
     Femtowatt, Attowatt, Zeptowatt, Yoctowatt, Horsepower,
+    /** @since 5.62 */
+    DecibelKilowatt, DecibelWatt, DecibelMilliwatt, DecibelMicrowatt,
 
     // Time
     Yottasecond = 11000, Zettasecond, Exasecond, Petasecond, Terasecond, Gigasecond, Megasecond,
@@ -325,7 +335,83 @@ enum UnitId {
     /** @since 5.27 */
     Zeptoohms,
     /** @since 5.27 */
-    Yoctoohms
+    Yoctoohms,
+
+    /** @since 5.53 */
+    Darcy = 33000,
+    /** @since 5.53 */
+    MiliDarcy,
+    /** @since 5.53 */
+    PermeabilitySquareMicrometer,
+
+    /** @since 5.61 */
+    Yobibyte = 34000,
+    /** @since 5.61 */
+    Yobibit,
+    /** @since 5.61 */
+    Yottabyte,
+    /** @since 5.61 */
+    Yottabit,
+    /** @since 5.61 */
+    Zebibyte,
+    /** @since 5.61 */
+    Zebibit,
+    /** @since 5.61 */
+    Zettabyte,
+    /** @since 5.61 */
+    Zettabit,
+    /** @since 5.61 */
+    Exbibyte,
+    /** @since 5.61 */
+    Exbibit,
+    /** @since 5.61 */
+    Exabyte,
+    /** @since 5.61 */
+    Exabit,
+    /** @since 5.61 */
+    Pebibyte,
+    /** @since 5.61 */
+    Pebibit,
+    /** @since 5.61 */
+    Petabyte,
+    /** @since 5.61 */
+    Petabit,
+    /** @since 5.61 */
+    Tebibyte,
+    /** @since 5.61 */
+    Tebibit,
+    /** @since 5.61 */
+    Terabyte,
+    /** @since 5.61 */
+    Terabit,
+    /** @since 5.61 */
+    Gibibyte,
+    /** @since 5.61 */
+    Gibibit,
+    /** @since 5.61 */
+    Gigabyte,
+    /** @since 5.61 */
+    Gigabit,
+    /** @since 5.61 */
+    Mebibyte,
+    /** @since 5.61 */
+    Mebibit,
+    /** @since 5.61 */
+    Megabyte,
+    /** @since 5.61 */
+    Megabit,
+    /** @since 5.61 */
+    Kibibyte,
+    /** @since 5.61 */
+    Kibibit,
+    /** @since 5.61 */
+    Kilobyte,
+    /** @since 5.61 */
+    Kilobit,
+    /** @since 5.61 */
+    Byte,
+    /** @since 5.61 */
+    Bit
 };
 
 class UnitCategory;
@@ -355,37 +441,37 @@ public:
     Unit();
 
     /**
-     * Copy constructor, copy @param other to this.
+     * Copy constructor, copy @p other to this.
      **/
     Unit(const Unit &other);
 
     virtual ~Unit();
 
     /**
-     * Assignment operator, assign @param other to this.
+     * Assignment operator, assign @p other to this.
      **/
     Unit &operator=(const Unit &other);
 
 #ifdef Q_COMPILER_RVALUE_REFS
     /**
-     * Move-assigns \a other to this Unit instance, transferring the
+     * Move-assigns @p other to this Unit instance, transferring the
      * ownership of the managed pointer to this instance.
      **/
     Unit &operator=(Unit &&other) { swap(other); return *this; }
 #endif
 
     /**
-     * Swaps this Unit with \a other. This function is very fast and never fails.
+     * Swaps this Unit with @p other. This function is very fast and never fails.
      **/
     void swap(Unit &other) { d.swap(other.d); }
 
     /**
-     * @return Returns true if this Unit is equal to the @param other Unit.
+     * @return @c true if this Unit is equal to the @p other Unit.
      **/
     bool operator==(const Unit &other) const;
 
     /**
-     * @return Returns true if this Unit is not equal to the @param other Unit.
+     * @return @c true if this Unit is not equal to the @p other Unit.
      **/
     bool operator!=(const Unit &other) const;
 
@@ -428,7 +514,7 @@ public:
      * @param value number value
      * @param fieldWidth width of the formatted field, padded by spaces.
      *                   Positive value aligns right, negative aligns left
-     * @param format type of floating point formating, like in QString::arg
+     * @param format type of floating point formatting, like in QString::arg
      * @param precision number of digits after the decimal separator
      * @param fillChar the character used to fill up the empty places when
      *                 field width is greater than argument width
@@ -441,7 +527,7 @@ public:
      * @param value number value
      * @param fieldWidth width of the formatted field, padded by spaces.
      *                   Positive value aligns right, negative aligns left
-     * @param format type of floating point formating, like in QString::arg
+     * @param format type of floating point formatting, like in QString::arg
      * @param precision number of digits after the decimal separator
      * @param fillChar the character used to fill up the empty places when
      *                 field width is greater than argument width
